Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6596)

Unified Diff: chrome/browser/safe_browsing/download_feedback_service.h

Issue 2439533002: Download Feedback Service should upload all eligible downloads (Closed)
Patch Set: make windows bots happy Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/safe_browsing/download_feedback_service.h
diff --git a/chrome/browser/safe_browsing/download_feedback_service.h b/chrome/browser/safe_browsing/download_feedback_service.h
index 48b1ee8b7486d15abecc09f48cefec29ce3a7aa2..474e4d80777f01e2549505834c546cc6235bcfa5 100644
--- a/chrome/browser/safe_browsing/download_feedback_service.h
+++ b/chrome/browser/safe_browsing/download_feedback_service.h
@@ -11,6 +11,7 @@
#include "base/macros.h"
#include "base/memory/ref_counted.h"
+#include "chrome/browser/download/download_commands.h"
#include "chrome/browser/safe_browsing/download_protection_service.h"
#include "content/public/browser/download_danger_type.h"
@@ -63,10 +64,11 @@ class DownloadFeedbackService {
static void RecordEligibleDownloadShown(
content::DownloadDangerType danger_type);
- // Begin download feedback for |download|. The |download| will be deleted
- // when this function returns. This must only be called if
- // IsEnabledForDownload is true for |download|.
- void BeginFeedbackForDownload(content::DownloadItem* download);
+ // Begin download feedback for |download|. Then delete download file if
+ // |download_command| is DISCARD, or run the KEEP command otherwise.This must
+ // only be called if IsEnabledForDownload is true for |download|.
+ void BeginFeedbackForDownload(content::DownloadItem* download,
+ DownloadCommands::Command download_command);
private:
static void BeginFeedbackOrDeleteFile(
« no previous file with comments | « chrome/browser/ntp_snippets/fake_download_item.cc ('k') | chrome/browser/safe_browsing/download_feedback_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698